@@ -1,7 +1,7 @@
 package Sort::Sub::naturally;
 
-our $DATE = '2015-09-27'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2015-10-07'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010;
 use strict;
@@ -12,8 +12,13 @@ sub gen_sorter {
 
     my $re = qr/([+-]?\d+|\D+)/;
 
-    package main;
     sub {
+        no strict 'refs';
+
+        my $caller = caller();
+        my $a = ${"$caller\::a"};
+        my $b = ${"$caller\::b"};
+
         my @a_parts = +($is_ci ? lc($a) : $a) =~ /$re/g;
         my @b_parts = +($is_ci ? lc($b) : $b) =~ /$re/g;
 
@@ -51,7 +56,7 @@ Sort::Sub::naturally - Sort naturally
 
 =head1 VERSION
 
-This document describes version 0.02 of Sort::Sub::naturally (from Perl distribution Sort-Sub), released on 2015-09-27.
+This document describes version 0.03 of Sort::Sub::naturally (from Perl distribution Sort-Sub), released on 2015-10-07.
 
 =for Pod::Coverage ^(gen_sorter)$
 
